# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from frontoffice.configuration import Configuration


class Settings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'env': 'str',
        'runtime': 'str'
    }

    attribute_map = {
        'env': 'env',
        'runtime': 'runtime'
    }

    def __init__(self, env='fb', runtime='basic', local_vars_configuration=None):  # noqa: E501
        """Settings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._env = None
        self._runtime = None
        self.discriminator = None

        if env is not None:
            self.env = env
        if runtime is not None:
            self.runtime = runtime

    @property
    def env(self):
        """Gets the env of this Settings.  # noqa: E501


        :return: The env of this Settings.  # noqa: E501
        :rtype: str
        """
        return self._env

    @env.setter
    def env(self, env):
        """Sets the env of this Settings.


        :param env: The env of this Settings.  # noqa: E501
        :type: str
        """

        self._env = env

    @property
    def runtime(self):
        """Gets the runtime of this Settings.  # noqa: E501


        :return: The runtime of this Settings.  # noqa: E501
        :rtype: str
        """
        return self._runtime

    @runtime.setter
    def runtime(self, runtime):
        """Sets the runtime of this Settings.


        :param runtime: The runtime of this Settings.  # noqa: E501
        :type: str
        """
        allowed_values = ["basic", "lambda", "serverless", "docker", "Unknown"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and runtime not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `runtime` ({0}), must be one of {1}"  # noqa: E501
                .format(runtime, allowed_values)
            )

        self._runtime = runtime

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Settings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Settings):
            return True

        return self.to_dict() != other.to_dict()
